@@ -36,8 +36,8 @@
         warning("Non euclidean distance")
     r <- sum(lambda > (lambda[1] * tol))
     if (scannf) {
-        if (exists("ade4TkGUIFlag") && ade4TkGUIFlag) {
-            nf <- chooseaxes(lambda, length(lambda))
+        if (exists("ade4TkGUIFlag")) {
+            nf <- ade4TkGUI::chooseaxes(lambda, length(lambda))
         } else {
             barplot(lambda)
             cat("Select the number of axes: ")
